@@ -496,6 +496,9 @@ class DynamoDBModel(object):
                         expected_db_values[name] = json.dumps(value, sort_keys=True)
                     elif value or value == 0:
                         expected_db_values[name] = value
+                    else:
+                        # Empty strings/sets must be represented as missing values
+                        expected_db_values[name] = False
             else:
                 # Forbid overwrites: do a conditional write on
                 # "this hash_key doesn't exist"
